#!/bin/sh

# Build script for Icecat
# Author: Ejis <ejis@mailoo.org>

# Homepage: http://www.gnu.org/software/gnuzilla/


set -e


SOFTNAME=icecat
VERSION=3.6.13
ZENVER=69
BUILD=1

CATEGORY=xap

MARCH=i686
FLAGS="-O2 -march=$MARCH -mtune=i686"

DOTNEW=1

CWD=$(pwd)

PKG=$SOFTNAME-$VERSION-$MARCH-$ZENVER.$BUILD

SOFTDIR=$CWD/$SOFTNAME-$VERSION
PKGDIR=$CWD/$PKG

PKGFILE=$PKGDIR.txz
MD5=$PKGDIR.md5
SRC=$PKGDIR.src
DEP=$PKGDIR.dep

SRCFILES=(
	$SOFTNAME-$VERSION.tar.bz2
	$SOFTNAME.patch
)

HOSTURL=http://zenwalk.pinguix.com/user-accounts/ejis/$CATEGORY/$SOFTNAME/$ZENVER
SRCURLS=(
	http://ftp.gnu.org/gnu/gnuzilla/$VERSION
	$HOSTURL
)

SRCLINKS=(
	${SRCURLS[0]}/${SRCFILES[0]}
	${SRCURLS[1]}/${SRCFILES[1]}
)

DOC=(
	$SOFTDIR/LEGAL
	$SOFTDIR/LICENSE
	$SOFTDIR/README.ICECAT
	$SOFTDIR/README.txt
)

EXTRADEPS=(
)

LESSDEPS=(
)


# Check for source files and download them if necessary

if [ ! -f ${SRCFILES[0]} ]; then
	wget -c -t 0 -T 50 -w 0 ${SRCLINKS[0]}
fi

if [ ! -f ${SRCFILES[1]} ]; then
	wget -c -t 0 -T 50 -w 0 ${SRCLINKS[1]}
fi


# Erase the previous build files

rm -rf $SOFTDIR $PKGDIR $MD5 $SRC $DEP $PKGFILE
mkdir -p $PKG


# Build

echo ""
echo "-----Building-----"
echo ""

tar -xvf $CWD/${SRCFILES[0]}

cd $SOFTDIR

export CFLAGS=$FLAGS
export CXXFLAGS=$FLAGS

patch -p1 < $CWD/${SRCFILES[1]}

sed -i \
	"s:ac_add_options --enable-optimize=\"-pipe -O3\":ac_add_options --enable-optimize=\"-pipe $FLAGS\":g" \
	./.mozconfig

./configure \
	--prefix=/usr \
	--localstatedir=/var \
	--sysconfdir=/etc \
	--mandir=/usr/man \
	--infodir=/usr/info \
	--with-x=yes \
	--enable-default-toolkit=cairo-gtk2 \
	--enable-update-packaging \
	--enable-application=browser \
	--enable-update-channel=release \
	--enable-tests \
	--enable-libxul \
	--disable-static \
	--disable-debug \
	--disable-updater \
	--disable-installer

make -j2
make DESTDIR=$PKGDIR install


#Remove icecat-devel-related items
rm -rvf $PKGDIR/usr/include
rm -rvf $PKGDIR/usr/lib/$SOFTNAME-devel-$VERSION


mkdir -p $PKGDIR/usr/share/icons/hicolor/48x48/apps
mkdir $PKGDIR/usr/share/applications


#symlinks to help those who could be lost with the name of the application
ln -vs ./$SOFTNAME $PKGDIR/usr/bin/firefox
ln -vs ./$SOFTNAME $PKGDIR/usr/bin/iceweasel


#symlink to a more generic Icecat so the langapacks wouldn't necessarly need an update
mv -v $PKGDIR/usr/lib/$SOFTNAME-$VERSION $PKGDIR/usr/lib/$SOFTNAME
ln -vs ./$SOFTNAME $PKGDIR/usr/lib/$SOFTNAME-$VERSION

#patch for startup homepage
sed -i \
	"s:browser.startup.homepage=http\://gnuzilla.gnu.org:browser.startup.homepage=http\://www.zenwalk.org/:g" \
	$PKGDIR/usr/lib/$SOFTNAME/browserconfig.properties

#patch to search the user's directory in ~/.mozilla/firefox
sed -i \
	"s:Vendor=GNUzilla:Vendor=Mozilla:g" \
	$PKGDIR/usr/lib/$SOFTNAME/application.ini
sed -i \
	"s:Name=IceCat:Name=Firefox:g" \
	$PKGDIR/usr/lib/$SOFTNAME/application.ini


convert -resize 48x48 -depth 8 \
	$PKGDIR/usr/lib/$SOFTNAME/icons/mozicon128.png \
	$PKGDIR/usr/share/icons/hicolor/48x48/apps/icecat.png


( cd $PKGDIR/usr/lib/$SOFTNAME/

#Replace included dictionaries with a link to zenwalk's dictionaries
rm -rvf ./dictionaries
ln -vs ../../share/myspell ./dictionaries 


#patches for locales
rm -v ./defaults/pref/firefox-branding.js

sed -i -e '/pref("general.useragent.locale", "en-US");/d' \
	./defaults/pref/firefox-l10n.js
sed -i -e '/pref("general.useragent.locale", "en-US");/d' \
	./defaults/pref/firefox.js
sed -i -e \
	's|pref(pref("general.useragent.locale", "chrome://global/locale/intl.properties");|pref("general.useragent.locale", "chrome://global/locale/intl.properties");|g' \
	./greprefs/all.js
sed -i -e \
	's/pref("intl.locale.matchOS",                 false);/pref("intl.locale.matchOS",                 true);/g' \
	./greprefs/all.js

echo "// Zenwalk package version" >> \
	./defaults/pref/vendor.js
echo "pref(\"general.useragent.extra.firefoxComment\",\"(Zenwalk GNU Linux)\");" >> \
	./defaults/pref/vendor.js
echo 'pref("browser.EULA.override", true);' >> \
	./defaults/pref/vendor.js

echo 'pref("network.protocol-handler.app.mailto", "icedove");' >> \
	./greprefs/all.js )


#Desktop file
cat << EOF > $PKGDIR/usr/share/applications/$SOFTNAME.desktop
[Desktop Entry]
Encoding=UTF-8
Exec=icecat %u
Icon=icecat
Type=Application
Terminal=false
MultipleArgs=false
Name=Icecat
GenericName=Web Browser
GenericName[af]=Web Blaaier
GenericName[ar]=متصفح ويب
GenericName[az]=Veb Səyyahı
GenericName[bg]=Браузър
GenericName[bn]=ওয়েব ব্রাউজার
GenericName[br]=Furcher ar Gwiad
GenericName[bs]=WWW Preglednik
GenericName[ca]=Fullejador web
GenericName[cs]=WWW prohlížeč
GenericName[cy]=Porydd Gwe
GenericName[da]=Browser
GenericName[de]=Web-Browser
GenericName[el]=Περιηγητής Ιστού
GenericName[eo]=TTT-legilo
GenericName[es]=Navegador web
GenericName[et]=Veebilehitseja
GenericName[eu]=Web arakatzailea
GenericName[fa]=مرورگر وب
GenericName[fi]=WWW-selain
GenericName[fo]=Alnótsfar
GenericName[fr]=Navigateur web
GenericName[gl]=Navegador Web
GenericName[he]=דפדפן אינטרנט
GenericName[hi]=वेब ब्राउज़र
GenericName[hr]=Web preglednik
GenericName[hu]=Webböngésző
GenericName[is]=Vafri
GenericName[it]=Browser Web
GenericName[ja]=ウェブブラウザ
GenericName[ko]=웹 브라우저
GenericName[lo]=ເວັບບຣາວເຊີ
GenericName[lt]=Žiniatinklio naršyklė
GenericName[lv]=Web Pārlūks
GenericName[mk]=Прелистувач на Интернет 
GenericName[mn]=Веб-Хөтөч
GenericName[nb]=Nettleser
GenericName[nds]=Nettkieker
GenericName[nl]=Webbrowser
GenericName[nn]=Nettlesar
GenericName[nso]=Seinyakisi sa Web
GenericName[pa]=ਵੈਬ ਝਲਕਾਰਾ
GenericName[pl]=Przeglądarka WWW
GenericName[pt]=Navegador Web
GenericName[pt_BR]=Navegador Web
GenericName[ro]=Navigator de web
GenericName[ru]=Веб-браузер
GenericName[se]=Fierpmádatlogan
GenericName[sk]=Webový prehliadač
GenericName[sl]=Spletni brskalnik
GenericName[sr]=Веб претраживач
GenericName[sr@Latn]=Veb pretraživač
GenericName[ss]=Ibrawuza yeWeb 
GenericName[sv]=Webbläsare
GenericName[ta]=வலை உலாவி
GenericName[tg]=Тафсиргари вэб
GenericName[th]=เว็บบราวเซอร์
GenericName[tr]=Web Tarayıcı
GenericName[uk]=Навігатор Тенет
GenericName[uz]=Веб-браузер
GenericName[ven]=Buronza ya Webu
GenericName[vi]=Trình duyệt Web
GenericName[wa]=Betchteu waibe
GenericName[xh]=Umkhangeli zincwadi we Web
GenericName[zh_CN]=网页浏览器
GenericName[zh_TW]=網頁瀏覽器
GenericName[zu]=Umcingi we-Web
MimeType=text/html
StartupNotify=false
Categories=Application;Network;
EOF


# Packaging

echo ""
echo "-----Packaging-----"
echo ""

cd $PKGDIR

mkdir -p $PKGDIR/install
mkdir -p $PKGDIR/usr/src/$SOFTNAME-$VERSION
mkdir -p $PKGDIR/usr/doc/$SOFTNAME-$VERSION


	   #|-----handy-ruler------------------------------------------------------|
cat > $PKGDIR/install/slack-desc <<EOF
$SOFTNAME: $SOFTNAME - The GNUzilla browser
$SOFTNAME:
$SOFTNAME: GNU IceCat is the GNU version of the Firefox browser. Its main
$SOFTNAME: advantage is an ethical one: it is entirely free software. While the
$SOFTNAME: principal source code from the Mozilla project is free software, they
$SOFTNAME: distribute and recommend non-free software as plug-ins and addons.
$SOFTNAME: 
$SOFTNAME: 
$SOFTNAME: 
$SOFTNAME: 
$SOFTNAME: 
EOF


# Redundent

if [ -d $PKGDIR/usr/share/doc ]; then
	mv $PKGDIR/usr/share/doc/$SOFTNAME/* $PKGDIR/usr/doc/$SOFTNAME-$VERSION/
	rm -rvf $PKGDIR/usr/share/doc
fi

if [ -d $PKGDIR/etc ]; then
	if [ $DOTNEW == 1 ]; then
		dotnewfiles=$(find $PKGDIR/etc -type f -print -exec \
			mv {} {}.new \;)
		cat << EOF > $PKGDIR/install/doinst.sh
dotnewfiles=(${dotnewfiles[@]})

for file in \${dotnewfiles[@]}; do
	if [ ! -f \$file ]; then
		mv \$file.new \$file
	fi
done
EOF
		sed -i "s:$PKGDIR/::g" $PKGDIR/install/doinst.sh
	fi
fi

find . | xargs file | grep "executable" | grep ELF | cut -f 1 -d : | \
	xargs strip --strip-unneeded 2> /dev/null || true
find . | xargs file | grep "shared object" | grep ELF | cut -f 1 -d : | \
	xargs strip --strip-unneeded 2> /dev/null || true

if [ -d $PKGDIR/usr/man ]; then
	
	( cd $PKGDIR/usr/man
		find . -type f -exec gzip -9 {} \;
		for i in $( find . -type l ) ; do ln -s $( readlink $i ).gz $i.gz ; rm $i ; done
	)
	
fi

if [ -d $PKGDIR/usr/info ]; then
	
	rm -f $PKGDIR/usr/info/dir
	gzip -9 $PKGDIR/usr/info/*.info*
	
fi

find . -name perllocal.pod \
	-o -name ".packlist" \
	-o -name "*.bs" \
	| xargs rm -f


cp -v $CWD/build-$SOFTNAME.sh \
	$CWD/${SRCFILES[1]} \
	$PKGDIR/usr/src/$SOFTNAME-$VERSION/

cp -rv	${DOC[@]} $PKGDIR/usr/doc/$SOFTNAME-$VERSION/


# fix permissions and ownership
find . -perm 777 -exec chmod 755 {} \;
find . -perm 775 -exec chmod 755 {} \;
find . -perm 666 -exec chmod 644 {} \;
find . -perm 664 -exec chmod 644 {} \;
find . -perm 600 -exec chmod 644 {} \;
find . -perm 444 -exec chmod 644 {} \;
find . -perm 400 -exec chmod 644 {} \;
find . -perm 440 -exec chmod 644 {} \;
find . -perm 511 -exec chmod 755 {} \;
find . -perm 711 -exec chmod 755 {} \;
find . -perm 555 -exec chmod 755 {} \;


fakeroot /sbin/makepkg -l y -c n $PKGFILE


cd $CWD

echo 'Creating .md5 file'
md5sum $PKG.txz > $MD5

echo 'Creating .src file'
echo "$HOSTURL/build-$SOFTNAME.sh" > $SRC
for link in ${SRCLINKS[@]}; do
	echo $link >> $SRC
done

echo 'Checking for dependencies'
deps=$(depfinder $PKGFILE)

for dep in ${EXTRADEPS[@]}; do
	deps="$deps,$dep"
done

for dep in ${LESSDEPS[@]}; do
	deps=${deps/$dep/}
done

order=$(echo ${deps//,/ } | sort -d)
echo ${order// /,} > $DEP

echo "Removing build directories"
rm -rf $SOFTDIR $PKG
